.. _glossary:

========
Glossary
========

.. glossary::

    simulant
        An individual or agent. One member of the population being simulated.

    attribute
        A variable associated with each simulant. For example, each simulant
        may have an attribute to describe their age or position.

    component
        Any self-contained piece of code that can be plugged into the
        simulation to add some functionality. In vivarium we typically think
        of components as encapsulating and managing some behavior or
        attributes of the simulants.
